/***********************************************************
 * $Id: MethodInfo.java 235 2011-02-05 16:52:09Z remoting $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 02.02.2011
 * 
 ***********************************************************/

package org.clazzes.remoting.maven;

import java.lang.reflect.Method;

/**
 * Information on a class method, which is possibly retrieved from
 * the java source.
 */
public class MethodInfo {

	private final Method method;
	private final String[] parameterNames;
	private final String   javaDoc;
	
	public MethodInfo(Method method) {
		this.method = method;
		this.parameterNames = null;
		this.javaDoc = null;
	}
	
	public MethodInfo(Method method, String[] parameterNames, String javaDoc) {
		this.method = method;
		this.parameterNames = parameterNames;
		this.javaDoc = javaDoc;
	}

	public String getName() {
		return this.method.getName();
	}
	
	public int getModifiers() {
		return this.method.getModifiers();
	}
	
	public Class<?> getReturnType() {
		return this.method.getReturnType();
	}
	
	public int getParameterCount() {
		return this.method.getParameterTypes().length;
	}
	
	public Class<?> getParameterType(int i) {
		return this.method.getParameterTypes()[i];
	}
	
	public String getParameterName(int i) {
		
		if (this.parameterNames == null || i >= this.parameterNames.length)
			return "arg" + i;
		
		return this.parameterNames[i];
	}
	
	public String getJavaDoc() {
		return this.javaDoc;
	}

	public Class<?>[] getParameterTypes() {
		
		return this.method.getParameterTypes();
	}

	public Method getMethod() {
		
		return this.method;
	}
}
